#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   types.py
# @Created At:  2023-02-07 13:08:55
# @Modified At: 2023-02-21 12:51:03
# @Modified By: thepoy

from typing import Union
from pathlib import Path

StrPath = Union[str, Path]
